Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(542)

Unified Diff: pkg/compiler/lib/src/resolution/signatures.dart

Issue 1969753002: Adjusts dart2js SSA builder to tolerate method type arguments. (Closed) Base URL: https://github.com/dart-lang/sdk.git@master
Patch Set: Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/compiler/lib/src/resolution/signatures.dart
diff --git a/pkg/compiler/lib/src/resolution/signatures.dart b/pkg/compiler/lib/src/resolution/signatures.dart
index 33a8f2f336bb0a62d8683a7c5e32d3a580581636..129262c97650bb2d5d9aabb59183fe7b6c173817 100644
--- a/pkg/compiler/lib/src/resolution/signatures.dart
+++ b/pkg/compiler/lib/src/resolution/signatures.dart
@@ -314,10 +314,11 @@ class SignatureResolver extends MappingVisitor<FormalElementX> {
nodes = nodes.tail;
TypeVariableElementX variableElement =
new TypeVariableElementX(variableName, element, index, node);
// TODO(eernst): When type variables are implemented fully we will need
// to resolve the actual bounds; currently we just claim [dynamic].
variableElement.boundCache = const DynamicType();
- TypeVariableType variableType = new TypeVariableType(variableElement);
+ TypeVariableType variableType =
+ new MethodTypeVariableType(variableElement);
variableElement.typeCache = variableType;
return variableType;
}, growable: false);
@@ -314,10 +314,11 @@ class SignatureResolver extends MappingVisitor<FormalElementX> {
TypeVariableElementX variableElement =
new TypeVariableElementX(variableName, element, index, node);
- // TODO(eernst): When type variables are implemented fully we will need
- // to resolve the actual bounds; currently we just claim [dynamic].
+ // TODO(eernst): When method type variables are implemented fully we
+ // must resolve the actual bounds; currently we just claim [dynamic].
variableElement.boundCache = const DynamicType();

Powered by Google App Engine
This is Rietveld 408576698